pub trait PropIndexMut<Idx>: IndexMut<Idx> {
// Provided methods
fn set_values_from<P, I>(&mut self, iter: I, source: &P)
where I: IntoIterator,
I::Item: IntoOwned<Idx>,
Idx: Clone,
P: Index<Idx, Output = Self::Output>,
Self::Output: Clone { ... }
fn set_values<I>(&mut self, iter: I, value: Self::Output)
where I: IntoIterator,
I::Item: IntoOwned<Idx>,
Self::Output: Clone { ... }
}Expand description
A property that can be read/write using indexing operations.
Provided Methods
Sourcefn set_values_from<P, I>(&mut self, iter: I, source: &P)
fn set_values_from<P, I>(&mut self, iter: I, source: &P)
Set the value associated with each key produced by iter to the value associated with the
key in the property source.
Sourcefn set_values<I>(&mut self, iter: I, value: Self::Output)
fn set_values<I>(&mut self, iter: I, value: Self::Output)
Set the value associated with keys produced by iter to value.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".